@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Application;
 
@@ -138,9 +138,8 @@ abstract class ApplicationBootstrap
         $this->setupAutoloader();
 
         if ($configDir === null) {
-            if (array_key_exists('ICINGAWEB_CONFIGDIR', $_SERVER)) {
-                $configDir = $_SERVER['ICINGAWEB_CONFIGDIR'];
-            } else {
+            $configDir = getenv('ICINGAWEB_CONFIGDIR');
+            if ($configDir === false) {
                 $configDir = Platform::isWindows()
                     ? $baseDir . '/config'
                     : '/etc/icingaweb2';
@@ -521,25 +520,6 @@ abstract class ApplicationBootstrap
         return $this;
     }
 
-    /**
-     * Set up the resource factory
-     *
-     * @return $this
-     */
-    protected function setupResourceFactory()
-    {
-        try {
-            $config = Config::app('resources');
-            ResourceFactory::setConfig($config);
-        } catch (NotReadableError $e) {
-            Logger::error(
-                new IcingaException('Cannot load resource configuration. An exception was thrown:', $e)
-            );
-        }
-
-        return $this;
-    }
-
     /**
      * Set up the user backend factory
      *
