@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Repository;
 
@@ -11,7 +11,7 @@ use Icinga\Data\Selectable;
 use Icinga\Exception\ProgrammingError;
 use Icinga\Exception\QueryException;
 use Icinga\Exception\StatementException;
-use Icinga\Util\String;
+use Icinga\Util\StringHelper;
 
 /**
  * Abstract base class for concrete repository implementations
@@ -789,7 +789,7 @@ abstract class Repository implements Selectable
     protected function retrieveCommaSeparatedString($value)
     {
         if ($value && is_string($value)) {
-            $value = String::trimSplit($value);
+            $value = StringHelper::trimSplit($value);
         } elseif ($value !== null) {
             throw new ProgrammingError('Cannot retrieve value "%s" as array. It\'s not a string', $value);
         }
@@ -903,8 +903,9 @@ abstract class Repository implements Selectable
         $blacklist = $this->getBlacklistedQueryColumns();
         $columns = array();
         foreach ($queryColumns[$table] as $alias => $column) {
-            if (! in_array(is_string($alias) ? $alias : $column, $blacklist)) {
-                $columns[$alias] = $this->resolveQueryColumnAlias($table, $alias);
+            $name = is_string($alias) ? $alias : $column;
+            if (! in_array($name, $blacklist)) {
+                $columns[$alias] = $this->resolveQueryColumnAlias($table, $name);
             }
         }
 
