@@ -1,4 +1,4 @@
-/*! Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/*! Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 /**
  * Icinga.Events
@@ -36,6 +36,12 @@
             var self = event.data.self;
             var icinga = self.icinga;
 
+            if (! icinga) {
+                // Attempt to catch a rare error, race condition, whatever
+                console.log('Got no icinga in applyHandlers');
+                return;
+            }
+
             if (self.initializeModules) {
                 var loaded = false;
                 var moduleName = $target.data('icingaModule');
@@ -89,12 +95,6 @@
             if ($searchField.length && $searchField.val().length) {
                 self.searchValue = $searchField.val();
             }
-
-            if (icinga.ui.isOneColLayout()) {
-                icinga.ui.disableCloseButtons();
-            } else {
-                icinga.ui.enableCloseButtons();
-            }
         },
 
         /**
@@ -161,6 +161,7 @@
         },
 
         onLoad: function (event) {
+            $('body').removeClass('loading');
             //$('.container').trigger('rendered');
         },
 
@@ -385,7 +386,9 @@
                 }
             }
 
-            icinga.loader.loadUrl(url, $target, data, method).progressTimer = progressTimer;
+            var req = icinga.loader.loadUrl(url, $target, data, method);
+            req.forceFocus = autosubmit ? $(event.currentTarget) : $button.length ? $button : null;
+            req.progressTimer = progressTimer;
 
             event.stopPropagation();
             event.preventDefault();
@@ -417,8 +420,8 @@
             var linkTarget = $a.attr('target');
             var $target;
             var formerUrl;
-            var remote = /^(?:[a-z]+:)\/\//;
-            if (href.match(/^(mailto|javascript):/)) {
+            if (href.match(/^(?:(?:mailto|javascript|data):|[a-z]+:\/\/)/)) {
+                event.stopPropagation();
                 return true;
             }
 
@@ -436,11 +439,6 @@
                 }
             }
 
-            // Let remote links pass through
-            if  (href.match(remote)) {
-                return true;
-            }
-
             // window.open is used as return true; didn't work reliable
             if (linkTarget === '_blank' || linkTarget === '_self') {
                 window.open(href, linkTarget);
@@ -471,7 +469,8 @@
 
             // This is an anchor only
             if (href.substr(0, 1) === '#' && href.length > 1
-                && href.substr(1, 1) !== '!') {
+                && href.substr(1, 1) !== '!'
+            ) {
                 icinga.ui.focusElement(href.substr(1), $a.closest('.container'));
                 return;
             }
@@ -484,7 +483,7 @@
             // If link has hash tag...
             if (href.match(/#/)) {
                 if (href === '#') {
-                    if ($a.hasClass('close-toggle')) {
+                    if ($a.hasClass('close-container-control')) {
                         if (! icinga.ui.isOneColLayout()) {
                             var $cont = $a.closest('.container').first();
                             if ($cont.attr('id') === 'col1') {
